$STITLE Input file: elas1.gms SAINT 1.01 CGE modeling system



*define the name of this file for reporting purpose
 SET
 INCELAS
 /
 elas2
 /
;
  elasfile('elas2') = 1  ;
$ontext

!!- In this includefile, the user inputs elasticities for consumption trade and production.
In case of privat consumption it is also possible to define a  specific neststructure.


Note that this file has to be consistent with your indata file in terms of numbers
of commodities. If you have several indata files you should thus have a specific set of
elas file for every specific indata file.

The file is divided into the following searchable blocks:

1. ELASTICITIES AND NEST STRUCTURE FOR HOUSEHOLD CONSUMPTION
2. TRADE ELASTICITIES
3. PRODUCTION FUNCTIONS

$offtext

*1. ELASTICITIES AND NEST STRUCTURE FOR HOUSEHOLD CONSUMPTION #################


*Household aggregate consumption function, intercept as share of wealth
*Note that a high value of cinst give a large intercept in the aggregate
*consumtpion function and thus a smaller mpc.
 cint(H) = 0.2;
*Household consumption nest structure====================


SET

*Define the different commodity groups here
 CGH
 /
 AHEAT
 ATRANS
 AMAN
 ASER
 /
 ;


*In the table below all commodities should be distributed to different aggregates
table usehcdef(C,CGH)    matrix to define the neststructure in consumption


             AHEAT         ATRANS         AMAN         ASER
C01           0             0              1            0
C10           0             0              1            0
C15           0             0              1            0
C20           0             0              1            0
C20bio        1             0              0            0
C232A         0             1              0            0
C232E         1             0              0            0
C24           0             0              1            0
C30           0             0              1            0
C401          1             0              0            0
C402          1             0              0            0
C403          1             0              0            0
C41           0             0              0            1
C50-52        0             0              0            1
C60           0             1              0            0
C63           0             0              0            1
C70           0             0              0            1
C75           0             0              0            1
C90           0             0              0            1

 ;



*=CHECK THE ROWSUMS IN ABOVE MATRIX=============================================
testhcdef(C)=    sum(CGH,   usehcdef(C,CGH))+0.1;
loop (C,
testhcdeft=testhcdef(C);
testhcdeftt $(testhcdeft>1.1) = 1/0;
testhcdeftt $(testhcdeft<1.1) = 1/0;
);
display
"if any element in the matrix below is not equal to 1.1 the corresponding row"
"in usehcdef does not sum to one and has to be adjusted"
 testhcdef;
*=END OF CHECK THE ROWSUMS IN ABOVE MATRIX======================================





*Household consumption elasticities====LES PART====================
*Note: The Frisch parameter is included in this section.


 FRISCH(H)       = -2;


*The LES demand system permits the user to specify expenditure elasticities for
*every specific commodity group CGH and household-specific Frisch parameters.
*(The Frisch parameter measures the elasticity of the marginal utility
*of income with respect to income.)
*If such information is not available the user may alternative specify
*all elasticities to be unity (as we do just below). If, in addition,
*the Frisch parameter is set at -1, the LES system collapses to a
*Cobb-Douglas system.




TABLE  LESELAS1(CGH,H) Exp'e elasticity of market dem for com c by hhd h

            H1        H2

AHEAT        1         1
ATRANS       1         1
AMAN         1         1
ASER         1         1

;



*Household consumption elasticities==CES PART======================

*In the table below define tha elasticity of substitution within the different
*aggregates

TABLE CGHELAS(H,CGH) Elasticity of substitution within the aggregates

             AHEAT         ATRANS         AMAN         ASER
H1            4              2             1.2         1.2
H2            4              2             1.2         1.2

;


*2. TRADE ELASTICITIES ####################################################

*note that for commodities where the assumption of imperfect substitutability
*is unrealistic sigmaarm and sigmacet should be fairly large. If we believe that
*import and export elasticities are small for other reasons than imperfect
*substitutability sigmaq should be smaller than sigmaarm and sigmat should be
*smaller than sigmacet. In most CGE models that totally relies in the armington
*assumptions sigmaq =sigmaarm and sigmat=sigmacet.

*In the table below C401 electricity is assumed to be a fairly homogenous
*good while the trade elasticities nevertheless are fairly small due to
*limitations in the transmission capacity.

table TRADELAS(AC,TRDELAS)    matrix to define the trade elasticities


             SIGMAQ         SIGMAT             SIGMAARM         SIGMACET
C01           1.1             2.6               1.1             2.6
C10           1.1             2.6               1.1             2.6
C15           1.1             2.6               1.1             2.6
C20           1.1             2.6               1.1             2.6
C232A         1.5             3                 1.5             3
C232E         1.5             3                 1.5             3
C24           1.1             2.6               1.1             2.6
C30           1.1             2.6               1.1             2.6
C401          2               3                 10              15
C402          0.8             1.1               0.8             1.1
C403          0.5             0.8               0.5             0.8
C41           0.5             0.8               0.5             0.8
C50-52        0.5             0.8               0.5             0.8
C60           0.8             2.3               0.8             2.3
C63           0.8             2.3               0.8             2.3
C70           0.4             0.8               0.4             0.8
C75           0.5             0.8               0.5             0.8
C90           0.6             1.2               0.6             1.2

 ;






*3. PRODUCTION FUNCTIONS ####################################################

*3.1 Substitutable intermediates nest structure==============================

* In the set below the commodities that are substitutables when used as
* intermediate inputs should be defined. The rest of the commodities would
* automatically be included in CLEO(C) and used in fixed proportions to output.

SET

 CSUBI(C)  commodities substitutable when used as intermediate
 /
 C20bio
 C232A
 C232E
 C401
 C402
 C403
 C60
 /

*Define the different commodity groups here
* If you have substitutable commodities, i.e. if the above set is nonempty, this set
* must have at least one element. If it only have one element the elasticity
* PRODELAS(A,'SIGMASUBI') will have no impact on the model and could as well
* have the default value.

 CGA
 /
 AHEAT
 ATRANS
 /
;


*In the table below all commodities should be distributed to different aggregates

Table proddefcsubi(CSUBI,CGA) matrix to define the neststructure of intermediates in production


             AHEAT         ATRANS

 C20bio        1             0
 C232A         0             1
 C232E         1             0
 C401          1             0
 C402          1             0
 C403          1             0
 C60           0             1
 ;

*If any column of above matrix has the sum of one, the corresponding
*CPRODELAS(A,CGA) will have no impact on the model and could as well have its
*default value.



*=CHECK THE ROWSUMS IN ABOVE MATRIX
 testdefcsubi(CSUBI)=    sum(CGA,   proddefcsubi(CSUBI,CGA))+0.1;
loop (CSUBI,
testdefcsubit(CSUBI)=testdefcsubi(CSUBI);
testdefcsubitt(CSUBI) $(testdefcsubit(CSUBI)>1.1) = 1/0;
testdefcsubitt(CSUBI) $(testdefcsubit(CSUBI)<1.1) = 1/0;
);
display
"if any element in the matrix below is not equal to 1.1 the corresponding row"
"in proddefcsubi does not sum to one and has to be adjusted"
 testdefcsubi;


*End off Substitutable intermediates nest structure=============================



*3.3 Elasticities===============================================================
*default values (do not change the following three line)
 CPRODELAS(A,CGA)           = 0.5  ;
 PRODELAS(A,PRDELAS)        = 0.5  ;


*Define specific elasticities here:
*if you want industry specific elasticities use a table.

*long run elasticities
 PRODELAS(A,'SIGMASC')      = 1.5  ;
 PRODELAS(A,'SIGMASUB')     = 0.8  ;
 PRODELAS(A,'SIGMASUBI')    = 0.6  ;
 PRODELAS(A,'SIGMALAB')     = 0.8  ;
 PRODELAS(A,'SIGMACAP')     = 1.5  ;
 CPRODELAS(A,'AHEAT')       =  4   ;
 CPRODELAS(A,'ATRANS')      =  2  ;



*parameter to define the "elasticity" of investments with respect to tobin q
 invpar(A,FCAP) = 1.5;
*parameter to define the return when net asset position abroad is equal to zero
  returnbal = 0.15;



*#*#*#*#*# THE END OF ELAS1.INC #*#*#*#*