$TITLE Static simulation file. SAINT 1.01 CGE modeling system


$OFFSYMLIST OFFSYMXREF

*For a well-tested model that solves without errors and needs no further
*debugging, you may overwrite the options that were specified in the
*file SAINTBASE.GMS by removing the asterisks in the first columns of the
*following two lines.
*OPTIONS ITERLIM=500000, LIMROW=0, LIMCOL=0
*      SOLPRINT=OFF ;

$ontext

The file contents in outline:
1. SETS FOR SIMULATIONS
2. DEFINING EXPERIMENT PARAMETERS
3. DEFINING CLOSURES FOR MACRO SYSTEM CONSTRAINTS
4. DEFINING CLOSURES FOR FACTOR MARKETS
5. REPORT SETUP
6. LOOP
7. COMPUTING PERCENTAGE CHANGE FOR REPORT PARAMETERS
8. CHECKING FOR GAP ERROR IN REPORT PARAMETERS


The purpose of the simulations that are implemented is to demonstrate
the use of the simulation file.

Note on standard steps when implementing a new simulation:

a. Add element to the set SIM (cf. TARCUT1)
b. If needed, declare new experiment parameter(s) (cf. TMSIM);
c. For the relevant experiment parameters, define default value
   (if new) and value for new simulation (cf. TMSIM).
d. Create report parameters (included in LOOPREP.INC and PERCCALC.INC)
   for each new model parameter that is subject to change in new
   experiments.
e. Verify that default macro and factor market closures are OK;
   if not, select different closures for the new simulation
   (see SICLOS, GOVCLOS, ROWCLOS, FACTFE, FMOBFE, FMOBUE)
f. In the beginning of the loop, impose the value of the
   experiment parameter. If the parameter is new, additional code
   is required (cf. tm and TMSIM in LOOP)
g. Include the simulation in SIMCUR.
h. Save and run the simulation file.


$offtext

*1. SETS FOR SIMULATIONS=============================================

SET
 SIM  simulations
 /
 BASE    base simulation
 tax20    20 % increase of taxes on fossil fuels
 permit20 20 % increase in the exogenous price of permits


 /

 EXA(A)   industries with tax exemptions
 /
 A01
 A15
 A20
 A24
 A30
 /

 SIMCUR(SIM)     current simulations
 SIMBASINIT(SIM) simulations with variable initialized at base level
 SIMMCP(SIM)     simulations solved as MCP problems
 SIMCURNB(SIM) current simulations other than base
 ;


*By defining SIMCUR, the user selects the experiments that are
*carried out. BASE should always be included in SIMCUR.

 SIMCUR(SIM)        = NO;
 SIMCUR('BASE')     = YES;
 SIMCUR('tax20') = YES;
 SIMCUR('permit20') = YES;


*Variable initialization at base level may provide a better starting
*point for selected simulations (depending on the content of the
*preceding simulation).
 SIMBASINIT(SIM) = NO;
 SIMBASINIT('tax20') = YES;
 SIMBASINIT('permit20') = YES;




*It is typically preferable to solve the MCP version of the model.
 SIMMCP(SIM)     = YES;



*define the set SIMCURNB
 SIMCURNB(SIMCUR) = YES;
 SIMCURNB('BASE') = NO;

DISPLAY SIMCUR, SIMBASINIT, SIMMCP, SIMCURNB;


*END: SETS FOR SIMULATIONS===========================================
*2. DEFINING EXPERIMENT PARAMETERS===================================

PARAMETERS
 TQSIM(C,P,SIM)       tax rate for com c by activity and sim
 QPERMITSIM(AETS,SIM)      domestic supply of permits
 PPERMITSIM(SIM)      exogenous price of permits
 PWMSIM(C,SIM)        price for imports of c in FCU
 PWESIM(C,SIM)        price for exports of c in FCU

*Closure variables that may be changed exogenously in simulations
*The values defined for these parameters matter only if the related
*variable is fixed
 FSAVSIM(SIM)         foreign savings by sim (FCU)
 IADJSIM(A,FCAP,SIM)  investment adjustment factor by sim
 IADJMSIM(SIM)        investment adjustment factor by sim
 EXRSIM(SIM)          exchange rate by sim
 GSAVSIM(SIM)         government savings by sim
 WFDISTSIM(F,A,SIM)   overprofits in industry and sim
 ;

*Unless specified otherwise below, base values are used

 TQSIM(C,PNE,SIM)  = tq0(C,PNE);


 FSAVSIM(SIM)         = FSAV0          ;
 IADJSIM(A,FCAP,SIM)  = IADJ0(A,FCAP)  ;
 IADJMSIM(SIM)        = IADJM0         ;
 EXRSIM(SIM)          = EXR0           ;
 GSAVSIM(SIM)         = GSAV0          ;
 PWMSIM(C,SIM)        = pwm0(C)        ;
 PWESIM(C,SIM)        = pwe0(C)        ;
 QPERMITSIM(AETS,SIM) = Qpermit0(AETS) ;
 PPERMITSIM(SIM)      = Ppermit0       ;
 WFDISTSIM(F,A,SIM)     = WFDIST0(F,A)        ;

*Specifying non-base values for experiment parameters



  TQSIM('C232A',PNE,'tax20')  = 1.2 * TQSIM('C232A',PNE,'base')   ;

  TQSIM('C232E',PNE,'tax20')  = 1.2 * TQSIM('C232E',PNE,'base')   ;

  TQSIM('C402',PNE,'tax20')  = 1.2 * TQSIM('C402',PNE,'base')   ;

  PPERMITSIM('permit20')      = 1.2 * Ppermit0   ;


DISPLAY
 TQSIM, FSAVSIM, IADJSIM, EXRSIM, GSAVSIM, PWMSIM
 ;


*END: DEFINING EXPERIMENT PARAMETERS=================================
*3. DEFINING CLOSURES FOR MACRO SYSTEM CONSTRAINTS=====

*The selection of values for  SICLOS, ROWCLOS, and GOVCLOS
*in this section determines the selection of variables that are fixed
*and flexible inside the solution LOOP.

PARAMETERS



 SICLOS(SIM) value for savings-investment closure
*SICLOS = 1 ---> inv-driven sav -- uniform mpc rate point change for
*                selected ins
*SICLOS = 2 ---> inv-driven sav -- scaled mpc for for selected ins
*SICLOS = 3 ---> inv is sav-driven
*SICLOS = 4 ---> inv is fixed abs share
*                - uniform mpc rate point change (cf. 1)
*SICLOS = 5 ---> inv is fixed abs share - scaled mpc (cf. 2)
*Note: SICLOS 4 and 5 are examples of balanced closures.
*SICLOS = 6 ---> both MPC and investments fixed. This closure requires
*                rowclos eq 3 both exchange rate and foregn saving flexible
*                Note if just one of SICLOS 6 and ROWCLOS 3 are chosen the other
*                will be chosen automatically.

 ROWCLOS(SIM) value for rest-of-world closure
*ROWCLOS = 1 ---> exch rate is flexible, for savings are fixed
*ROWCLOS = 2 ---> exch rate is fixed   , for savings are flexible
*ROWCLOS = 3 ---> both exchange rate and foregn saving flexible,
*                 this closure requires SICLOS = 6 both saving and inv. fixed.
*                Note if just one of SICLOS 6 and ROWCLOS 3 are chosen the other
*                will be chosen automatically.
*ROWCLOS = 4 ---> both exchange rate and foregn saving fixed,
*                  if you have a closed economy this closure has to be used.

 GOVCLOS(SIM) value for government closure
*GOVCLOS = 1 ---> gov savings are flexible, dir tax rate is fixed
*GOVCLOS = 2 ---> gov savings are fixed   ,
*                 uniform dir tax rate point change for selected ins
*GOVCLOS = 3 ---> gov savings are fixed   ,
*                 scaled dir tax rate for selected institutions
*GOVCLOS = 4 ---> gov savings are fixed   ,
*                 scaled dir factor tax rate for all kinds of labour
*GOVCLOS = 5 ---> gov savings are fixed   ,
*                 scaled dir factor tax rate for all kinds of capital


 MPC01SIM(INSD,SIM)   0-1 par for potential flexing of savings rates
 TINS01SIM(INSD,SIM)  0-1 par for potential flexing of dir tax rates
 ;


* SICLOS, ROWCLOS, and GOVCLOS are set at default values

 SICLOS(SIM)     = 1;
 ROWCLOS(SIM)    = 1;
 GOVCLOS(SIM)    = 1;


$ontext
For closures with flexible savings or direct tax rates, the default is
that the rates of all domestic non-government institutions adjust. If
you deviate from the default, make sure that, for both parameters and
for simulations using the indicated closures, the value of at least one
element in H is unity. (If not, the parameters ERRMPC01 and
ERRTINS01 will generate errors.)
$offtext

 MPC01SIM(H,SIM)   = 1;
 TINS01SIM(H,SIM)  = 1;

*selecting industry and capital good for flexible investment demand
*This setting only matters for some of the alternative
*savings-investment closures.




*Here: overwrite values for  SICLOS, ROWCLOS, and GOVCLOS for
*selected simulations


 SICLOS(SIMCURNB)= 2;

 ROWCLOS(SIMCURNB)= 1;

 GOVCLOS(SIMCURNB)= 4;






PARAMETERS

 ERRMPC01(SIM)  UNDF if MPC01SIM not unity for at least one H
*In order for SICLOS 1, 2, 4 and 5 to work, MPC01SIM has to have a value of
*unity for at least one element in H for every SIM. If this is not
*the case, an error is generated. Solution: change the definition if
*MPC01SIM.

 ERRTINS01(SIM)  UNDF if TINS01SIM not unity for at least one H
*In order for GOVCLOS 2 and 3 to work, TINS01SIM has to have a value of
*unity for at least one element in H for every SIM. If this is not
*the case, an error is generated. Solution: change the definition if
*TINS01SIM.
 ;

 ERRMPC01(SIM)$(((SICLOS(SIM) EQ 1) OR (SICLOS(SIM) EQ 2) OR (SICLOS(SIM) EQ 4) OR (SICLOS(SIM) EQ 5))
  AND (SUM(H$(MPC01SIM(H,SIM) EQ 1), 1) LT 1)) = 1/0;

 ERRTINS01(SIM)$(((GOVCLOS(SIM) EQ 2) OR (GOVCLOS(SIM) EQ 3))
  AND (SUM(H$(TINS01SIM(H,SIM) EQ 1), 1) LT 1)) = 1/0;

DISPLAY
 SICLOS, GOVCLOS, ROWCLOS, MPC01SIM, TINS01SIM, ERRMPC01, ERRTINS01
 ;



*END: DEFINING CLOSURES FOR MACRO SYSTEM CONSTRAINTS=================
*4. DEFINING CLOSURES FOR FACTOR MARKETS=============================

*Inside the solution loop, the selection of values for FMOBFE, FACTFE,
*and FMOBUE determine the selection of variables that are fixed
*and flexible.


PARAMETERS
 FMOBFE(F,SIM)  factor f is fully employed & mobile in sim
 FACTFE(F,SIM)  factor f is fully employed & activity-specific in sim
 FMOBUE(F,SIM)  factor f is unemployed & mobile in sim
 ;
*Default specification of factor market closures
*Note that, for every simulation, every factor should have a non-zero
*value for exactly one of the three parameters.

 FMOBFE(FLAB,SIM) = 1;
 FACTFE(FLAB,SIM) = 0;
 FMOBUE(FLAB,SIM) = 0;

 FMOBFE(FCAP,SIM) = 1;
 FACTFE(FCAP,SIM) = 0;
 FMOBUE(FCAP,SIM) = 0;



*If no value is specified for a factor, impose FMOBFE:
 FMOBFE(F,SIM)$(FMOBFE(F,SIM) + FACTFE(F,SIM) + FMOBUE(F,SIM) EQ 0) = 1;



*Here: overwrite values for FMOBFE, FACTFE, and FMOBUE for selected
*factors and simulations



*Checking for errors in factor market closures

PARAMETER
 ERRFCLOS(F,SIM) UNDF error if not exactly one closure by f and sim
*Error if any factor f, in each simulation, does not have a non-zero
*value for exactly one of the three parameters FMOBFE, FACTFE, FMOBUE.
 ;
 ERRFCLOS(F,SIM)$(FMOBFE(F,SIM)+ FACTFE(F,SIM)+ FMOBUE(F,SIM) NE 1) = 1/0;

DISPLAY ERRFCLOS, FMOBFE, FACTFE, FMOBUE;


*5. REPORT SETUP=================================================



$INCLUDE REPPAR.INC



*====================================================================
*6. L O O P==========================================================
*====================================================================
LOOP(SIMCUR,

*This include statement is optional. It may facilitate solver
*performance by providing better starting point.
IF(SIMBASINIT(SIMCUR),
$INCLUDE VARINIT.INC
);



*IMPOSING PARAMETER  & FIXED VARIABLE VALUES FOR EXPERIMENTS=========
*In this section, changes in experiment parameters and fixed
*variables are imposed, except for changes in fixed variables related to
*closures, which are handled in the next section.


 Ppermit= PPERMITSIM(SIMCUR)   ;
 Qpermit(A)=0 ;
 Qpermit(AETS)= QPERMITSIM(AETS,SIMCUR)   ;

  tq(C,PNE) = TQSIM(C,PNE,SIMCUR) ;
display "loop 1", tq;
 tq(FOSSILPERM,AETS) = tq(FOSSILPERM,AETS) + carbshare(FOSSILPERM) * Ppermit;
display "loop 1", tq;
 PWM.FX(C) = PWMSIM(C,SIMCUR);
 PWE.FX(C) = PWESIM(C,SIMCUR);




*IMPOSING CLOSURES FOR SYSTEM CONSTRAINTS============================

*Selecting institutions with potentially flexible savings and direct
*tax rates. This setting only matters for some of the alternative
*savings-investment and government closures.
 mpc01(H)  = MPC01SIM(H,SIMCUR);
 tins01(H) = TINS01SIM(H,SIMCUR);



*-------------


*-------------


* If rowclos = 3 siclos is automatically adjusted to 6
IF(ROWCLOS(SIMCUR) EQ 3,
   SICLOS(SIMCUR) = 6;
  );

IF(SICLOS(SIMCUR) EQ 1,
*Investment-driven savings
*Uniform MPC rate point change for selected ins
*Fixed investment demand quantity adjustment factors
*Flexible absorption shares for investment demand
 MPCADJ.FX = MPCADJ0;
 DMPC.LO = -INF; DMPC.UP = +INF; DMPC.L = DMPC0;
 IADJ.FX(A,FCAP)       = IADJSIM(A,FCAP,SIMCUR);
 IADJM.FX         = IADJMSIM(SIMCUR)  ;
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand
 GADJ.FX    = GADJ0;
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 2,
*Investment-driven savings
*Scaled MPC for selected institutions
*Fixed investment demand quantity adjustment factors
*Flexible absorption shares for investment demand
 MPCADJ.LO = -INF; MPCADJ.UP = +INF; MPCADJ.L = MPCADJ0;
 DMPC.FX = DMPC0;
 IADJ.FX(A,FCAP) = IADJSIM(A,FCAP,SIMCUR);
 IADJM.FX         = IADJMSIM(SIMCUR)  ;
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand
 GADJ.FX    = GADJ0;
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 3,
*Savings-driven investment
*Fixed marginal savings propensities
*Flexible investment demand quantity adjustment factors
*Flexible absorption shares for investment demand
 MPCADJ.FX = MPCADJ0;
 DMPC.FX = DMPC0;
 IADJ.FX(A,FCAP) = IADJSIM(A,FCAP,SIMCUR);
 IADJM.LO = -INF; IADJM.UP = +INF; IADJM.L = IADJM0  ;
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand
 GADJ.FX    = GADJ0;
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 4,
*Balanced closure.
*Uniform MPC rate point change for selected ins
*Flexible investment demand quantity adjustment factors for selected A and FCAP
*Fixed absorption shares for investment demand
 MPCADJ.FX = MPCADJ0;
 DMPC.LO = -INF; DMPC.UP = +INF; DMPC.L = DMPC0;
 IADJ.FX(A,FCAP) = IADJSIM(A,FCAP,SIMCUR);
 IADJM.LO = -INF; IADJM.UP = +INF; IADJM.L = IADJM0  ;
 INVSHR.FX = INVSHR0;
*Flexible government demand quantity adjustment factors
*Fixed absorption share for government demand
 GADJ.LO = -INF; GADJ.UP = +INF;  GADJ.L = GADJ0;
 GOVSHR.FX = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 5,
*Balanced closure.
*Scaled MPC for selected institutions
*Flexible investment demand quantity adjustment factors
*Fixed absorption shares for investment demand
 MPCADJ.LO = -INF; MPCADJ.UP = +INF; MPCADJ.L = MPCADJ0;
 DMPC.FX = DMPC0;
 IADJ.FX(A,FCAP) = IADJSIM(A,FCAP,SIMCUR);
 IADJM.LO = -INF; IADJM.UP = +INF; IADJM.L = IADJM0  ;
 INVSHR.FX = INVSHR0;
*Flexible government demand quantity adjustment factors
*Fixed absorption share for government demand
 GADJ.LO = -INF; GADJ.UP = +INF;  GADJ.L = GADJ0;
 GOVSHR.FX = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 6,
*both saving and investments fixed
*both exchange rate and foregn saving flexible
 MPCADJ.FX = MPCADJ0;
 DMPC.FX = DMPC0;
 IADJ.FX(A,FCAP)       = IADJSIM(A,FCAP,SIMCUR);
 IADJM.FX         = IADJMSIM(SIMCUR)  ;
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*This closure requires rowclos eq 3
 ROWCLOS(SIMCUR)= 3;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand
 GADJ.FX    = GADJ0;
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

*-------------


IF(GOVCLOS(SIMCUR) EQ 1,
*Fixed direct tax rates
*Flexible government savings
 TLABADJ.FX = TLABADJ0;
 TFINADJ.FX = TFINADJ0;
 TINSADJ.FX = TINSADJ0;
 DTINS.FX = DTINS0;
 GSAV.LO = -INF; GSAV.UP = +INF; GSAV.L = GSAV0;
 );

IF(GOVCLOS(SIMCUR) EQ 2,
*Uniform direct tax rate point change for selected institutions
*Fixed government savings
 TLABADJ.FX = TLABADJ0;
 TFINADJ.FX = TFINADJ0;
 TINSADJ.FX = TINSADJ0;
 DTINS.LO = -INF; DTINS.UP = +INF; DTINS.L = DTINS0;
 GSAV.FX = GSAVSIM(SIMCUR);
 );

IF(GOVCLOS(SIMCUR) EQ 3,
*Scaled direct tax rates for selected institutions
*Fixed government savings
 TLABADJ.FX = TLABADJ0;
 TFINADJ.FX = TFINADJ0;
 TINSADJ.LO = -INF; TINSADJ.UP = +INF; TINSADJ.L = TINSADJ0;
 DTINS.FX = DTINS0;
 GSAV.FX = GSAVSIM(SIMCUR);
 );

IF(GOVCLOS(SIMCUR) EQ 4,
*Scaled labor tax rates
*Fixed government savings
 TINSADJ.FX = TINSADJ0;
 DTINS.FX = DTINS0;
 TLABADJ.LO = -INF; TLABADJ.UP = +INF; TLABADJ.L = TINSADJ0;
 TFINADJ.FX = TFINADJ0;
 GSAV.FX = GSAVSIM(SIMCUR);
 );

IF(GOVCLOS(SIMCUR) EQ 5,
*Scaled capital tax rates
*Fixed government savings
 TINSADJ.FX = TINSADJ0;
 DTINS.FX = DTINS0;
 TLABADJ.FX = TLABADJ0;
 TFINADJ.LO = -INF; TFINADJ.UP = +INF; TFINADJ.L = TINSADJ0;
 GSAV.FX = GSAVSIM(SIMCUR);
 );




*-------------

IF(ROWCLOS(SIMCUR) EQ 1,
*Fixed foreign savings -- flexible exchange rate
 FSAV.FX = FSAVSIM(SIMCUR);
 EXR.LO  = -INF; EXR.UP  = +INF; EXR.L   = EXR0;
 );

IF(ROWCLOS(SIMCUR) EQ 2,
*Fixed exchange rate -- flexible foreign savings
 EXR.FX = EXRSIM(SIMCUR);
 FSAV.LO = -INF; FSAV.UP = +INF; FSAV.L = FSAV0;
 );

IF(ROWCLOS(SIMCUR) EQ 3,
*Flexible exchange rate -- flexible foreign savings
 EXR.LO  = -INF; EXR.UP  = +INF; EXR.L   = EXR0;
 FSAV.LO = -INF; FSAV.UP = +INF; FSAV.L = FSAV0;
 );

IF(ROWCLOS(SIMCUR) EQ 4,
*Fixed foreign savings -- fixed exchange rate closed economy case
 FSAV.FX = FSAVSIM(SIMCUR);
 EXR.FX = EXRSIM(SIMCUR);

 );

*----------------------------------------------------------------------
*Loop over all factors for alternative factor-market closures.



LOOP(F,

*---
*Factors with FMOBFE(F,SIMCUR) = 1 are fully employed and mobile between
*activities. WF(F) is the market-clearing variable each factor.

IF(FMOBFE(F,SIMCUR) EQ 1,

 WFDIST.FX(F,A)      = WFDIST0(F,A);
 QFS.FX(F)           = QFS0(F);

 WF.LO(F)            = -INF;
 WF.UP(F)            = +INF;
 WF.L(F)             = WF0(F);

 QF.LO(F,A)$QF0(F,A) = -INF;
 QF.UP(F,A)$QF0(F,A) = +INF;
 QF.L(F,A)$QF0(F,A)  = QF0(F,A); );

*---
*Factors with FACTFE(F,SIMCUR) = 1 are fully employed and
*activity-specific. WFDIST(F,A) is the clearing variable, one for each
*segment of the factor market.

IF(FACTFE(F,SIMCUR) EQ 1,

 WF.FX(F)                = WF0(F);

 QF.FX(F,A)              = QF0(F,A);
*obs the row below is changed just to test the difference
*Note that this impies that fixing factors to activities fix them to the level of the previous simulation
* QF.FX(F,A)              = QF.L(F,A);


 WFDIST.LO(F,A)$QF0(F,A) = -INF;
 WFDIST.UP(F,A)$QF0(F,A) = +INF;
 WFDIST.L(F,A)$QF0(F,A)  = WFDIST0(F,A);

 QFS.LO(F)               = -INF;
 QFS.UP(F)               = +INF;
 QFS.L(F)                = QFS0(F); );

*---
*Factors with FMOBUE(F,SIMCUR) = 1 are unemployed and mobile. For each
*activity, the wage, WFDIST(F,A)*WF(F), is fixed. QFS(F) is the
*market-clearing variable for the unified labor market.

IF(FMOBUE(F,SIMCUR) EQ 1,

 WFDIST.FX(F,A)      = WFDIST0(F,A);
 WF.FX(F)            = WF0(F);

 QF.LO(F,A)$QF0(F,A) = -INF;
 QF.UP(F,A)$QF0(F,A) = +INF;
 QF.L(F,A)$QF0(F,A)  = QF0(F,A);

 QFS.LO(F)           = -INF;
 QFS.UP(F)           = +INF;
 QFS.L(F)            = QFS0(F); );
*---
 );
*End loop for factor-market closures.

*SOLVING=============================================================








IF(SIMMCP(SIMCUR) ,
 SOLVE MCPCGE USING MCP ;
ELSE
 SOLVE NLPCGE USING NLP MINIMIZING WALRASSQR;

 );



*DEFINING REPORT VALUES FOR SIMCUR===================================


$BATINCLUDE SIMREP.INC SIMCUR


 );



*====================================================================
*END: L O O P========================================================
*====================================================================

*7. COMPUTING PERCENTAGE CHANGE FOR REPORT PARAMETERS================


$INCLUDE REPPERC.INC





*8. CHECKING FOR ERRORS IN SOLUTION AND REPORT PARAMETERS============

*If error in the negative price/quantity segment, one or more solution prices
*or quantities are negative.

NEGPWARN(C,SIM)$
  ((PDSX(C,SIM) LT 0) OR
  (PEX(C,SIM)  LT 0) OR (PMX(C,SIM) LT 0)  OR
  (PQX(C,SIM) LT 0)  OR (PWEX(C,SIM) LT 0) OR
  (PWMX(C,SIM) LT 0) OR (PXX(C,SIM) LT 0 ))
  = 1/0;

NEGQWARN(C,SIM)$
  ((QDX(C,SIM) LT 0) OR (QEX(C,SIM)  LT 0) OR
  (QTX(C,SIM) LT 0)  OR  (QXX(C,SIM) LT 0) OR
  (QMX(C,SIM) LT 0)  OR (QQX(C,SIM) LT 0) OR
  (QGX(C,SIM) LT 0)  OR (SMIN((H,CGH), QHX(H,C,CGH,SIM)) LT 0) OR
  (SMIN(A, QINTX(C,A,SIM)) LT 0)  OR (SMIN((A,FCAP), QINVX(C,A,FCAP,SIM)) LT 0) )
  = 1/0;

NEGWFWARN(F,SIM)$
 ((WFX(F,SIM) LT 0) OR (SMIN(A, WFDISTX(F,A,SIM)) LT 0) )
  = 1/0;

NEGQFWARN(F,SIM)$
 ((QFSX(F,SIM) LT 0) OR (SMIN(A, QFX(F,A,SIM)) LT 0) )
  = 1/0;

Display
  NEGPWARN, NEGQWARN, NEGWFWARN, NEGQFWARN
"Negative prices and quantities are economically illegal"
""
 ;


 GAPWARN(SIM)$(GDPGAP(SIM) GT 0.1) = 1/0;

Display

GAPWARN
"If error here, check displays of GDPGAP to find it and fix it."
GDPGAP
 ;


*If error here, SOLVEREP reports illegal values.
 SOLVEWARN(SOLVEIND,MODTYPE,SIM)
  $(SOLVEREP(SOLVEIND,MODTYPE,SIM) GT SOLVEMAX(SOLVEIND,MODTYPE)) = 1/0;

 Display

SOLVEWARN
"If error(s) (UNDF), one or more SOLVEREP values are illegal."
SOLVEREP

"MODEL STATUS:"
" 1 OPTIMAL"
" 2 LOCALLY OPTIMAL"
" 3 UNBOUNDED"
" 4 INFEASIBLE"
" 5 LOCALLY INFEASIBLE"
" 6 INTERMEDIATE INFEASIBLE"
" 7 INTERMEDIATE NON-OPTIMAL"
" 8 INTEGER SOLUTION"
" 9 INTERMEDIATE NON-INTEGER"
"10 INTEGER INFEASIBLE"
"11 (UNUSED)"
"12 ERROR UNKNOWN"
"13 ERROR NO SOLUTION"
""
"SOLVER STATUS:"
" 1 NORMAL COMPLETION"
" 2 ITERATION INTERRUPT"
" 3 RESOURCE INTERRUPT"
" 4 TERMINATED BY SOLVER"
" 5 EVALUATION ERROR LIMIT"
" 6 UNKNOWN"
" 7 (UNUSED)"
" 8 ERROR PREPROCESSOR ERROR"
" 9 ERROR SETUP FAILURE"
"10 ERROR SOLVER FAILURE"
"11 ERROR INTERNAL SOLVER ERROR"
"12 ERROR POST-PROCESSOR ERROR"
"13 ERROR SYSTEM FAILURE"
""
"NUM-REDEFEQ shows the number of redefined equations (should be zero)"
""


 ;


*If error here, check displays of SAMBUDGAP for hints about the source
 WALRASWARN(SIM)$(ABS(WALRASX(SIM)) GT 0.3) = 1/0;


OPTION
 QFX:3:1:1    , QHX:3:1:1      , QINTX:3:1:1  , WFAX:3:1:1
 WFAX:3:1:1   , WFDISTX:3:1:1  , YFINX:3:1:1   , YFLABX:3:1:1    , CPIX:6

 QFXP:3:1:1   , QHXP:3:1:1     , QINTXP:3:1:1, WFAXP:3:1:1
 WFAXP:3:1:1  , WFDISTXP:3:1:1


 GDPTAB1:3:1:1,
 GDPTAB1P:3:1:1
 GDPTAB2:3:1:1,
 GDPTAB2P:3:1:1
 MACCLOS:0,     FACCLOS:0:1:1
 SOLVEREP:0:1:1
 ;



DISPLAY


"The parameters MACCLOS and FACCLOS, and the sets ACES and ALEO"
"indicate the values for model features with user choice."

 MACCLOS
 "For GOV"
 "  1 -> gov savings are flexible, dir tax rate is fixed"
 "  2 -> gov savings are fixed"
 "       uniform dir tax rate point chng for selected ins"
 "  3 -> gov savings are fixed"
 "       scaled dir tax rate for selected institutions"
 "  4 -> gov savings are fixed"
 "       scaled dir factor tax rate for all kinds of labour"
 "  5 -> gov savings are fixed"
 "       scaled dir factor tax rate for all kinds of capital"



 ""
 "For ROW"
 "  1 -> exch rate is flexible, for savings are fixed"
 "  2 -> exch rate is fixed   , for savings are flexible"
 "  3 -> both exchange rate and foregn saving flexible"
 "       this closure requires SICLOS = 6 both saving and inv. fixed"
 "  4 -> both exchange rate and foregn saving fixed"
 "       if you have a closed economy this closure has to be used"


 ""
 "For S-I"
  "1 -> inv-driven sav -- uniform mpc rate point chng for selected ins"
  "2 -> inv-driven sav -- scaled mpc for selected ins"
  "3 -> inv is sav-driven"
  "4 -> inv is fixed abs share - uniform mpc rate chng (cf. 1)"
  "5 -> inv is fixed abs share - scaled mpc (cf. 2)"
  "6 -> both MPC and investments fixed."
  "     this closure requires ROWCLOS = 3"
  "     both exchange rate and foregn saving flexible"
 ""
 FACCLOS
 "FMOBFE = 1 -> mobile and fully employed"
 "FACTFE = 1 -> activity-specific and fully employed"
 "FMOBUE = 1 -> mobile and unemployed"


$ontext



$offtext
 SIMBASINIT
 "For simulations in SIMBASINIT, the variables are initialized at"
 "base levels."
 ""


WALRASWARN


;

$include simxldump.gms

$include carbon_advanced_new_permit.gms

*$include datacreator.gms

*#*#*#*#*# THE END OF simLS01.GMS #*#*#*#*
