$TITLE Redistribution of secondary products SAINT CGE modeling system 1.01


$ONTEXT
This file is a tool for treatment of secondary products in the Static CGE model
SAINT1.01 documented in:
SAINT Manual
A Standard CGE model for Advanced Analysis of Indirect Taxation;
Lars Bohlin
University of rebro

After runnning this program search for:

Matrices to be copied into the new indata file

in the LST file. Copy these matrices and past them into a new indata file.


The file SAINT_SEC.GMS consists of the following segments (with
searchable headings):

1. DESCRIPTION OF THE TREATMENT OF SECONDARY PRODUCTS

2. SET DECLARATIONS

3. PARAMETER DECLARATIONS

4. OPTIONS
chose technology assumptions, minimum limit for the size of cells in usetable, and
what secondary products to remove.

5. VARIABLE AND EQUATION DECLARATIONS

6. EQUATION DEFINITIONS AND MODEL STATEMENT

7. CALCULATION OF TECHNOLOGICAL COEFFICIENTS FOR INTERMEDIATE INPUTS

8. CALCULATION OF TECHNOLOGICAL COEFFICIENTS FOR LABOUR INPUTS

9. CALCULATION OF NEW INDATA






$offtext










$ONSYMLIST ONSYMXREF OFFUPPER
*The command on the next line makes it possible to use xllink in if statements
$libinclude xllink
*$OFFSYMLIST OFFSYMXREF
$ONEMPTY
*The dollar control option makes empty data initialization statements
*permissible (e.g. sets without elements or parameters without data)

$ontext
1. DESCRIPTION OF THE TREATMENT OF SECONDARY PRODUCTS

By running this procedure all or a subset of secondary products are removed
to the industry where thay are the main product together with an appropriate vector
of inputs. What secondary products that should be removed are definen in the file insec.INC

$offtext


*2. SET DECLARATIONS ################################################

$ontext

In this section, all sets are declared.

$offtext

SETS


 AC               global set for model accounts - aggregated microsam accounts
 ACNT(AC)         all elements in AC except TOTAL
 P(AC)            all purchasers
 PNI(P)           all purchasers except investments
 A(PNI)           activities
 PNE(PNI)         all purchasers except exports and investments
 CGH            set to define different nest in the utility function
 CGA            set to define different nest in csubi of the production function
 INCELAS          set to define elasticity settings
 INCDAT           set to define used indata

 C(AC)            commodities
 CD(C)            commodities with domestic sales of output
 CDN(C)           commodities without domestic sales of output
 CE(C)            exported commodities
 CEN(C)           non-export commodities
 CM(C)            imported commodities
 CMN(C)           non-imported commodities
 CX(C)            commodities with output
 CTR(C)           commodities used for trade margins
 CLEO(C)          commodities with leontief technology when used as inputs
 CSUBI(C)         commodities with ces technology when used as inputs

 F(AC)            factors
 INS(P)           institutions
 INSD(PNI)        domestic institutions
 INSNG(INS)       non-government institutions
 H(INSD)          households

 CINV(C)          fixed investment goods
 CGOV(C)          commodities consumed by government



 FLAB(F)      labor
 FCAP(F)      capital
 FOP(FCAP)    capital that is used to adjustments in SAINTSEC


 SOLVEIND  solve indicators
 /
 MODEL-STATUS    model status
 SOLVER-STATUS   solver status
 OBJ-VALUE       value of objective function
 NUM-REDEFEQ     number of redefined equations
 /


 PRDELAS prod elasticities
 /
 SIGMASC    elasticity qsc nest
 SIGMASUB   elasticity qsub nest
 SIGMASUBI  elasticity between sustitutables intermediate inputs
 SIGMALAB   elasticity between labour
 SIGMACAP   elasticity between capital
 /

*SIGMAARM is the elasticity of substitution between imports
*and domestic output in domestic demand.
*SIGMACET is the elasticity of transformation for domestic
*marketed output between exports and domestic supplies.
*SIGMAQ is the price elasticity of imports
*SIGMAT is the price elasticity of exports

 TRDELAS  trade elasticities
 /
 SIGMAQ     import elasticity
 SIGMAT     export elasticity
 SIGMAARM   elasticity of substitution in armington equation
 SIGMACET   elasticity of substitution in CET equation
 /




 rknt(C)  subset with non zero knt
 /
 /



 rjnt(A)  subset with non zero jnt
 /
 /
 ;

*ALIAS statement to create identical cets
ALIAS
 (AC,ACP)  , (ACNT,ACNTP), (A,AP),  (C,CP)
 (CE,CEP)  , (CM,CMP)    , (CLEO,CLEOP) , (CSUBI,CSUBIP)
 (F,FP)    , (FLAB,FLABP), (FCAP,FCAPP) , (CGH,CGHP)
 (INS,INSP), (INSD,INSDP), (H,HP)
 (CTR,CTRP), (CGA,CGAP)
 ;



*3. PARAMETER DECLARATIONS ##########################################




 PARAMETERS
 binvmat(C,A)            the matrix of investments at basic prices
 capdef(C,FCAP)          Parameter to define which goods are included in fcap
 FNAP0                   forreign net asset position base year
 indatafile(INCDAT)      parameter to remined you about your indata file
 my                      Weight for commodity technology assumption
 omega                   Weight for industry technology assumption
 weighted                If this number is set equal to one a weighted model is calculated
 Netpermit0          net between demestic supply and domestic use of CO2 permits
 SOLVERCHOICE            Parameter to choose between nlp and mcp
 scaling                 scaling factor for indata
 secprod(A,C)            defining which secondary products that are not allowed
 primact(A,C)            defining which industry that is the main producer
 smallusecell            defining minimum cell in use table
 SAM(AC,ACP)             standard SAM
 SAMBALCHK(AC)           column minus row total for SAM
 SAMMAN(AC,ACP)          manipulations in the SAM
 Ppermit0                exogenous price of CO2 permits
 PSUP(C)                 initial basic price for commodity c
 proddefcsubi(CSUBI,CGA) matrix to define the neststructure of intermediates in prod func
 PRODELAS(A,PRDELAS)     elasticity of substittion in production functions by activity
 Qpermit0(A)             domestic supply of CO2 permits per industry
 usehcdef(C,CGH)         matrix to define the neststructure in consumption
 testdefcsubi(CSUBI)     parameter to test that the rows of the proddefcsubi sum to 1
 testdefcsubit           parameter to test that the rows of the proddefcsubi sum to 1
 testdefcsubitt          parameter to test that the rows of the proddefcsubi sum to 1
 testdeflab(FLAB)        parameter to test that the rows of the proddeflab sum to 1
 testdeflabt             parameter to test that the rows of the proddeflab sum to 1
 testdeflabtt            parameter to test that the rows of the proddeflab sum to 1
 testhcdef(C)            parameter to test that the rows of the usehcdef sum to 1
 testhcdeft              parameter to test that the rows of the usehcdef sum to 1
 testhcdeftt             parameter to test that the rows of the usehcdef sum to 1
 tminv(C,A)              trade margins on investments
 tmmat(C,P)              disaggregated trade margins
 tqinv(C,A)              disaggregated quantity tax on investments
 tqmat(C,P)              disaggregated quantity tax
 tvinv(C,A)              disaggregated value tax on investments
 tvmat(C,P)              disaggregated value tax


 tsup(c)            total supply of commodity c
 tisup(A)           total supply of activity a
 wsup(C,A)          The industries share of total supply of commodity c
 wisup(C,A)         The commodities share of total supply of activity a

 kn(C)              Number of industries producing commodity c
 jni(CP,A)          Number of commodities produced in industry a and using commodity cp
 gg                 parameter for temporary purposes
 ggg                parameter for temporary purposes
 tk(CP,C)           average technological coefficient use of cp in production of c

 ut(C,A)            temporary usetable
 utl(A)             temporary usetable in loop
 vt(A,C)            temporary supply table
 jnt(A)             Temporary number of comodities
 jni(CP,A)          Number of commodities produced in industry a and using commodity cp
 jnl(FLAB,A)        Number of commodities produced in industry A and using labour LAB


*parameters for report variabels

 repvark(AC,C)      variance per commodity
 repvarj(AC,A)      variance per industry
 bcof(AC,C,A)       industry specific technological coefficients

 SOLVEREPIO(solveind,AC)
 error(AC)          parameter to define the inputs that didn't solve correctly


 repvark2(AC,C)     variance per commodity
 repvarj2(AC,A)     variance per industry
 bcof2(AC,C,A)      industry specific technological coefficients

 SOLVEREPIO2(solveind,AC)
 error2(AC)         parameter to define the inputs that didn't solve correctly

 repvark3(AC,C)     variance per commodity
 repvarj3(AC,A)     variance per industry
 bcof3(AC,C,A)      industry specific technological coefficients

 SOLVEREPIO3(solveind,AC)
 error3(AC)          parameter to define the inputs that didn't solve correctly

 repvark4(AC,C)     variance per commodity
 repvarj4(AC,A)     variance per industry
 bcof4(AC,C,A)      industry specific technological coefficients

 SOLVEREPIO4(solveind,AC)
 error4(AC)          parameter to define the inputs that didn't solve correctly

 bcofdef(AC,C,A)     industry specific technological coefficients to be used

*parameters for corrections of the SAM and its submatrices
 ERRSAMBAL(AC)       parameter to create error message if unbalanced SAM
 makecorr1(A,C)      outputs that should be removed
 makecorr2(A,C)      outputs that should be added
 usecorr1(CP,C,A)    inputs that should be removed
 usecorr2(CP,C,A)    inputs that should be added
 usecorr(C,A)        netcorrections of usetable
 labcorr1(FLAB,C,A)  labour inputs that should be removed
 labcorr2(FLAB,C,A)  labour inputs that should be added
 labcorr(FLAB,A)     netcorrections of labour usetable
 makecorr(A,C)       netcorrections of maketable
 make(C)             check that all corections in make sum to zero
 use(C)              check that all corections in use sum to zero

 TMusecorr(C,A)      net corrections of tmmat
 TMusecorr1(CP,C,A)  trade margins that follows the inputs to be removed
 TMusecorr2(CP,C,A)  trade margins to be added acourding the origin of the added inputs
 TVusecorr(C,A)      net corrections of tvmat
 TVusecorr1(CP,C,A)  value taxes that follows the inputs to be removed
 TVusecorr2(CP,C,A)  value taxes to be added acourding the origin of the added inputs
 TQusecorr(C,A)      net corrections of tqmat
 TQusecorr1(CP,C,A)  quantity taxes that follows the inputs to be removed
 TQusecorr2(CP,C,A)  quantity taxes to be added acourding the origin of the added inputs
 SYMSAM(AC,ACP)      SAM constructed of the WSSYM procedure
 SYMTM(C,A)          adjustments in tmmat
 SYMTQ(C,A)          adjustments in tqmat
 SYMTV(C,A)          adjustments in tvmat
 capadj(A)           adjustment of cap to avoid negative or small operating surplus
 useadj1(C,A)        adjustments in usetable to avoid small cells
 useadj(C)           sum off adjustments in usetable to avoid small cells
 labadj(FLAB)        sum of adjustments mad in labour use table
 tmmatadj(C,A)       adjustments in order to avoid trade margins on zero inputs
 tqmatadj(C,A)       adjustments in order to avoid quantity taxes on zero inputs
 tvmatadj(C,A)       adjustments in order to avoid value taxes on zero inputs
 tmadj1(C)           adjustments in order to balance trade margins per trade commodity
 tmadj               adjustments in order to balance total trade margins
 tqadj               adjustments in order to balance total quantity taxes
 tvadj               adjustments in order to balance total value taxes

 ;

*Default values of option parameters
*Do not change the following lines, adjustments are to be made in
*the Options section.




 SOLVERCHOICE   = 0;
 scaling        = 1;




*4. OPTIONS ###############################################################
*In this section most off the options for the SAINTBASE.GMS are specified #
*##########################################################################

*CHOICE OF INDATA ==========================================

*INCLUDE ONE COUNTRY DATA SET

*DATA REQUIREMENTS
$ontext
The datafile would include a SAM where trademargins, value-taxes and
quantity-taxes are in totals. These three rows would be specified on products
in three tables named: tmmat(C,P), tqmat(C,P) and tvmat(C,P)

Note that the use table in the sam SAM(C,AC) should be in basic prices for all
accounts except of the exports in 'ROW' where it should be with export taxes
included (or in most cases with export subsidies subtracted) but without trade
margins. Trademargins on export should be specified in tmmat.
================================================================================
$offtext

*Remove asterisk in front of ONE (AND ONLY ONE) of the following lines
*or add a new line for a new file with country data

$INCLUDE INDATA.INC




*=SCALING OF INDATA=============================================================
*For scaling all indata remove the 1 and put in an appropriate number. All
*data would be divided with this number.

 scaling = 1;

*=END OF SCALING OF INDATA======================================================
*===============================================================================

*OPTIONs FOR THE PROCEDURE DEALING WITH SECONDARY PRODUCTS======================



*Different technology assumptions defined by the three parameters below could be
*used in the WSSYM procedure

*Weight for industry technology assumption
 omega          = 0.0001  ;
*Weight for commodity technology assumption
 my             = 1 ;

*As a result of this procedure small cells may occur in the SAM. These are set to
*zero if thay are smaller than the number specified below
 smallusecell = 2 ;
*read in indatafile where main producer is defined for every product and the secondary products
*that should be removed are defined



$INCLUDE insec.INC


*===============================================================================
*Scaling of Indata:
 SAM(AC,ACP)  = SAM(AC,ACP)/scaling;
 TQMAT(C,P)   = TQMAT(C,P)/scaling;
 TVMAT(C,P)   = TVMAT(C,P)/scaling;
 TMMAT(C,P)   = TMMAT(C,P)/scaling;
 binvmat(C,A) = binvmat(C,A)/scaling;
 TQINV(C,A)   = TQINV(C,A)/scaling;
 TVINV(C,A)   = TVINV(C,A)/scaling;
 TMINV(C,A)   = TMINV(C,A)/scaling;

 QFBASE(F,A)  =  QFBASE(F,A) / scaling;






*SAM adjustments ===============================================================
*In this section, some minor adjustments are made in the SAM (when
*needed) to fit the model structure.




*Eliminating payments of any account to itself.
 SAM(ACNT,ACNT) = 0;
*







*5. VARIABLE AND EQUATION DECLARATIONS #########################################
variable
OB               Objective function in minimizing problem
;

Positive Variables


bt(C,A)          temporary b coeficients in minimizing problem



vark(C)          Variance of b
varj(A)          Variance of b


;



Equations
varkeq(C)          Variance of b in commodity dimension
varjeq(A)          Variance of b in industry dimension
OBJ                Objective function
UBV(A)             B compatible with make and use matrices


;
*END OF VARIABLE AND EQUATION DECLARATIONS DECLARATIONS=========================

*6. EQUATION DEFINITIONS AND MODEL STATEMENT ###################################

varkeq(rknt)..    vark(rknt) =e= 1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt(rknt,A)))
                 ;


varjeq(rjnt)..    varj(rjnt) =e= 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt(C,rjnt)))
                   ;


OBJ..    OB =e= SUM(rknt, vark(rknt)) + SUM(rjnt, varj(rjnt))   ;


UBV(A)..      utl(A) =e= SUM(C, bt(C,A)*vt(A,C))  ;





*MODEL STATEMENT================================================================

Model iomodel
/
varkeq
varjeq
OBJ
UBV

/
 ;


*iomodel.optfile = 1 ;


iomodel.holdfixed = 1 ;


*END OF EQUATION DEFINITIONS AND MODEL STATEMENT ===============================

*7. CALCULATION OF TECHNOLOGICAL COEFFICIENTS FOR INTERMEDIATE INPUTS ##########


*EXTRACTING DATA FROM THE SAM AND CALCULATE THE PARAMETERS NEEDED ==============

 ut(C,A) = sam(C,A);
 vt(A,C) = sam(A,C);

display ut, vt;
 tsup(C)  =  sum(A,  vt(A,C));
 tisup(A)  =  sum(C,  vt(A,C));
 wsup(C,A)$tsup(C)  =  vt(A,C)/tsup(C);
 wisup(C,A)$tisup(A)  =  vt(A,C)/tisup(A);






*COUNTING INDUSTRIES PRODUCING COMMODITY J =====================================

* ge alla vrdet 0


kn(C)=0;


* counting non-zeros in make table
loop(A,
loop(C,
gg=vt(A,C);
if (gg > 0,
 kn(C)=kn(C)+1;

);
));


* counting non-zeros in make and use tables

jni(CP,A)=0 ;


loop(CP,
loop(A,
loop(C,
ggg=vt(A,C);
gg=ut(CP,A);
if (ggg > 0 and gg > 0,

 jni(CP,A)=jni(CP,A)+1;
);
)));
Display jni,  kn ;

*SOLVER LOOP STARTS HERE========================================================
*Industry soecific technological coeficients is calculated row by row by
*minimizing their variances

loop (CP,

*temporary parameter values

jnt(A)=jni(CP,A)  ;


utl(A) = ut(CP,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)=utl(A)/sam('total',A);





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                   ;

 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;








*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO('MODEL-STATUS',CP)  = IOMODEL.MODELSTAT;
 SOLVEREPIO('SOLVER-STATUS',CP) = IOMODEL.SOLVESTAT;
 SOLVEREPIO('OBJ-VALUE',CP)  = OB.L;

 error(CP)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark(CP,C) = vark.L(C) ;
 repvarj(CP,A) = varj.L(A) ;
 bcof(CP,C,A) = bt.L(C,A) ;

  );


*RERUNNING INPUTS THAT DIDN'T SOLVE PROPERLY====================================
*the modell will be rescaled and solved two more times.
my=my/8;
omega=omega/8;

loop (CP,
if (error(cp)=1,
*temporary parameter values

jnt(A)=jni(CP,A)  ;


utl(A) = ut(CP,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A) = 0;
BT.L(C,A)$(bcof(CP,C,A) > 0) = bcof(CP,C,A) ;





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                  ;

 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;





*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO2('MODEL-STATUS',CP)  = IOMODEL.MODELSTAT;
 SOLVEREPIO2('SOLVER-STATUS',CP) = IOMODEL.SOLVESTAT;
 SOLVEREPIO2('OBJ-VALUE',CP)  = OB.L;

 error2(CP)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark2(CP,C) = vark.L(C) ;
 repvarj2(CP,A) = varj.L(A) ;
 bcof2(CP,C,A) = bt.L(C,A) ;
  );
  );

my=my*8;
omega=omega*8;
*rerunning inputs that didn't solve properly

my=my/64;
omega=omega/64;

loop (CP,
if (error2(cp)=1,
*temporary parameter values

jnt(A)=jni(CP,A)  ;


utl(A) = ut(CP,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)= bcof2(CP,C,A) ;





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                  ;

 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;





*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO3('MODEL-STATUS',CP)  = IOMODEL.MODELSTAT;
 SOLVEREPIO3('SOLVER-STATUS',CP) = IOMODEL.SOLVESTAT;
 SOLVEREPIO3('OBJ-VALUE',CP)  = OB.L;

 error3(CP)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark3(CP,C) = vark.L(C) ;
 repvarj3(CP,A) = varj.L(A) ;
 bcof3(CP,C,A) = bt.L(C,A) ;
  );
  );

my=my*64;
omega=omega*64;

*rerunning inputs that didn't solve properly

my=my/512;
omega=omega/512;

loop (CP,
if (error3(cp)=1,
*temporary parameter values

jnt(A)=jni(CP,A)  ;


utl(A) = ut(CP,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)= bcof3(CP,C,A);





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                  ;

 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;






*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO4('MODEL-STATUS',CP)  = IOMODEL.MODELSTAT;
 SOLVEREPIO4('SOLVER-STATUS',CP) = IOMODEL.SOLVESTAT;
 SOLVEREPIO4('OBJ-VALUE',CP)  = OB.L;

 error4(CP)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark4(CP,C) = vark.L(C) ;
 repvarj4(CP,A) = varj.L(A) ;
 bcof4(CP,C,A) = bt.L(C,A) ;
  );
  );

my=my*512;
omega=omega*512;







 bcofdef(CP,C,A)= bcof(CP,C,A) ;

 bcofdef(CP,C,A)$error(CP) = 0 ;

 bcofdef(CP,C,A) =  bcofdef(CP,C,A)+bcof2(CP,C,A) ;

 bcofdef(CP,C,A)$error2(CP) = 0 ;

 bcofdef(CP,C,A) =  bcofdef(CP,C,A)+bcof3(CP,C,A) ;

 bcofdef(CP,C,A)$error3(CP) = 0 ;

 bcofdef(CP,C,A) =  bcofdef(CP,C,A)+bcof4(CP,C,A) ;


*8. CALCULATION OF TECHNOLOGICAL COEFFICIENTS FOR LABOUR INPUTS ################

* counting non-zeros in make and labour tables

jnl(FLAB,A)=0 ;


loop(FLAB,
loop(A,
loop(C,
ggg=vt(A,C);
gg=SAM(FLAB,A);
if (ggg > 0 and gg > 0,

 jnl(FLAB,A)=jnl(FLAB,A)+1;
);
)));



loop (FLAB,

*temporary parameter values

jnt(A)=jnl(FLAB,A)  ;


utl(A) = SAM(FLAB,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)=utl(A)/sam('total',A);





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                  ;


 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;







*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO('MODEL-STATUS',FLAB)  = IOMODEL.MODELSTAT;
 SOLVEREPIO('SOLVER-STATUS',FLAB) = IOMODEL.SOLVESTAT;
 SOLVEREPIO('OBJ-VALUE',FLAB)  = OB.L;

 error(FLAB)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark(FLAB,C) = vark.L(C) ;
 repvarj(FLAB,A) = varj.L(A) ;
 bcof(FLAB,C,A) = bt.L(C,A) ;

  );


*RERUNNING INPUTS THAT DIDN'T SOLVE PROPERLY====================================
*the modell will be rescaled and solved two more times.
my=my/8;
omega=omega/8;

loop (FLAB,
if (error(FLAB)=1,
*temporary parameter values

jnt(A)=jnl(FLAB,A)  ;


utl(A) = SAM(FLAB,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)= bcof(FLAB,C,A) ;





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                   ;



 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;







*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO2('MODEL-STATUS',FLAB)  = IOMODEL.MODELSTAT;
 SOLVEREPIO2('SOLVER-STATUS',FLAB) = IOMODEL.SOLVESTAT;
 SOLVEREPIO2('OBJ-VALUE',FLAB)  = OB.L;

 error2(FLAB)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark2(FLAB,C) = vark.L(C) ;
 repvarj2(FLAB,A) = varj.L(A) ;
 bcof2(FLAB,C,A) = bt.L(C,A) ;
  );
  );

my=my*8;
omega=omega*8;

*rerunning inputs that didn't solve properly

my=my/64;
omega=omega/64;

loop (FLAB,
if (error2(FLAB)=1,
*temporary parameter values

jnt(A)=jnl(FLAB,A)  ;


utl(A) = SAM(FLAB,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)= bcof2(FLAB,C,A);





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                  ;

 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;



*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO3('MODEL-STATUS',FLAB)  = IOMODEL.MODELSTAT;
 SOLVEREPIO3('SOLVER-STATUS',FLAB) = IOMODEL.SOLVESTAT;
 SOLVEREPIO3('OBJ-VALUE',FLAB)  = OB.L;

 error3(FLAB)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark3(FLAB,C) = vark.L(C) ;
 repvarj3(FLAB,A) = varj.L(A) ;
 bcof3(FLAB,C,A) = bt.L(C,A) ;
  );
  );

my=my*64;
omega=omega*64;

*rerunning inputs that didn't solve properly

my=my/512;
omega=omega/512;

loop (FLAB,
if (error3(FLAB)=1,
*temporary parameter values

jnt(A)=jnl(FLAB,A)  ;


utl(A) = SAM(FLAB,A);



*initilizing variables

BT.UP(C,A) = INF;
BT.LO(C,A) = 0;
BT.L(C,A)= bcof3(FLAB,C,A);





loop (A,
gg=utl(A);
if (gg=0 ,
BT.FX(C,A) = 0;
);
);

loop (C,
loop (A,
gg=vt(A,C) ;
if (gg=0 ,
BT.FX(C,A) = 0;
);
);
);



*Recreation of subsets
rknt(C) = NO ;
rknt(C)$(kn(C) gt 1) = yes ;

rjnt(A) = NO ;
rjnt(A)$(jnt(A) gt 1) = yes ;



*display rknt, rjnt;

*initilizing the rest of the variables

vark.L(rknt) =  1/(kn(rknt)-1)*(SUM(A$(vt(A,rknt) gt 0),
                  (my*bt.L(rknt,A))**2)-1/kn(rknt)*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A))*
                  SUM(A$vt(A,rknt), my*bt.L(rknt,A)))
                  ;

varj.L(rjnt)  = 1/(jnt(rjnt)-1)*(SUM(C$(vt(rjnt,C) gt 0),
                  (omega*bt.L(C,rjnt))**2)-1/jnt(rjnt)*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt))*
                  SUM(C$vt(rjnt,C), omega*bt.L(C,rjnt)))
                  ;

 OB.L  = SUM(rknt, vark.L(rknt)) + SUM(rjnt, varj.L(rjnt))   ;




*=======================================================================*

solve iomodel using nlp minimizing ob;


 SOLVEREPIO4('MODEL-STATUS',FLAB)  = IOMODEL.MODELSTAT;
 SOLVEREPIO4('SOLVER-STATUS',FLAB) = IOMODEL.SOLVESTAT;
 SOLVEREPIO4('OBJ-VALUE',FLAB)  = OB.L;

 error4(FLAB)$(IOMODEL.MODELSTAT gt 2) = 1;


*=======================================================================*



*=======================================================================*




 repvark4(FLAB,C) = vark.L(C) ;
 repvarj4(FLAB,A) = varj.L(A) ;
 bcof4(FLAB,C,A) = bt.L(C,A) ;
  );
  );

my=my*512;
omega=omega*512;

 bcofdef(FLAB,C,A)= bcof(FLAB,C,A) ;

 bcofdef(FLAB,C,A)$error(FLAB) = 0 ;

 bcofdef(FLAB,C,A) =  bcofdef(FLAB,C,A)+bcof2(FLAB,C,A) ;

 bcofdef(FLAB,C,A)$error2(FLAB) = 0 ;

 bcofdef(FLAB,C,A) =  bcofdef(FLAB,C,A)+bcof3(FLAB,C,A) ;

 bcofdef(FLAB,C,A)$error3(FLAB) = 0 ;

 bcofdef(FLAB,C,A) =  bcofdef(FLAB,C,A)+bcof4(FLAB,C,A) ;

*END OFF CALCULATION OF TECHNOLOGICAL COEFFICIENTS FOR LABOUR INPUTS ===========


*9. CALCULATION OF NEW INDATA  #################################################

*Calculation of new use and make tables=========================================

secprod(A,C)=secprod(A,C)*vt(A,C);
makecorr1(A,C)=0;
makecorr2(A,C)=0;
usecorr1(CP,C,A)=0;
usecorr2(CP,C,A)=0;
labcorr1(FLAB,C,A)=0;
labcorr2(FLAB,C,A)=0;

loop(C,
loop(A,

if (secprod(A,C) > 0,

makecorr1(A,C) = - SAM(A,C) ;
makecorr2(AP,C) = makecorr2(AP,C) + SAM(A,C) * primact(AP,C) ;
usecorr1(CP,C,A) = - SAM(A,C)*bcofdef(CP,C,A);
usecorr2(CP,C,AP) = usecorr2(CP,C,AP) - usecorr1(CP,C,A) * primact(AP,C);
labcorr1(FLAB,C,A) = - SAM(A,C)*bcofdef(FLAB,C,A);
labcorr2(FLAB,C,AP) = labcorr2(FLAB,C,AP) - labcorr1(FLAB,C,A) * primact(AP,C)

 );
 );
 );


makecorr(A,C) = makecorr1(A,C) + makecorr2(A,C);
usecorr(CP,A) = SUM(C, usecorr1(CP,C,A) + usecorr2(CP,C,A));
labcorr(FLAB,A) = SUM(C, labcorr1(FLAB,C,A) + labcorr2(FLAB,C,A));
make(C) = sum(A, makecorr(A,C) ) ;
use(C) = sum(A, usecorr(C,A)) ;

*Calculation of new tax and trade margins matrices==============================

TMusecorr1(CP,C,A)$SAM(CP,A)= usecorr1(CP,C,A)*tmmat(CP,A)/SAM(CP,A);
TMusecorr2(CP,C,AP) = - SUM(A, TMusecorr1(CP,C,A) * primact(AP,C));
TMusecorr(CP,A) = SUM(C, TMusecorr1(CP,C,A) + TMusecorr2(CP,C,A));
TVusecorr1(CP,C,A)$SAM(CP,A)= usecorr1(CP,C,A)*tvmat(CP,A)/SAM(CP,A);
TVusecorr2(CP,C,AP) = - SUM(A, TVusecorr1(CP,C,A) * primact(AP,C));
TVusecorr(CP,A) = SUM(C, TVusecorr1(CP,C,A) + TVusecorr2(CP,C,A));
TQusecorr1(CP,C,A)$SAM(CP,A)= usecorr1(CP,C,A)*tqmat(CP,A)/SAM(CP,A);
TQusecorr2(CP,C,AP) = - SUM(A, TQusecorr1(CP,C,A) * primact(AP,C));
TQusecorr(CP,A) = SUM(C, TQusecorr1(CP,C,A) + TQusecorr2(CP,C,A));

display makecorr1, makecorr2, usecorr1, usecorr2, usecorr, makecorr, make, use
labcorr1
labcorr2
labcorr
TMusecorr1
TMusecorr2
TVusecorr1
TVusecorr2
TQusecorr1
TQusecorr2
;
SYMSAM(AC,ACP) = SAM(AC,ACP) ;
SYMSAM(A,C) = SAM(A,C) + makecorr(A,C);
SYMSAM(C,A) = SAM(C,A) + usecorr(C,A);

*REMOVING SMALLCELLS IN USETABLE================================================
loop(C,
loop(A,
if (SYMSAM(C,A) < SMALLUSECELL,
useadj1(C,A) = -  SYMSAM(C,A);
SYMSAM(C,A) = 0;
);
);
);


useadj(C)= sum(A, useadj1(C,A));
*balancing commodities acount
SYMSAM(A,C)=SYMSAM(A,C)+ useadj(C)*primact(A,C) ;


*END OFF REMOVING SMALLCELLS IN USETABLE========================================

*adjusting trade margins and taxes on commodities===============================
tmmat(C,A) = tmmat(C,A) + TMusecorr(C,A);
TQMAT(C,A) = TQMAT(C,A) + TQusecorr(C,A);
TVMAT(C,A) = TVMAT(C,A) + TVusecorr(C,A);

*remove taxes and trade margins in case of seros in use
tmmatadj(C,A) = 0;
tqmatadj(C,A) = 0;
tvmatadj(C,A) = 0;
tmmatadj(C,A)$(SYMSAM(C,A) eq 0) = - tmmat(C,A) ;
tqmatadj(C,A)$(SYMSAM(C,A) eq 0) = - tqmat(C,A);
tvmatadj(C,A)$(SYMSAM(C,A) eq 0) = - tvmat(C,A);
tmmat(C,A) = tmmat(C,A) + tmmatadj(C,A);
TQMAT(C,A) =  TQMAT(C,A)  + tqmatadj(C,A);
TVMAT(C,A) =  TVMAT(C,A)  + tvmatadj(C,A);

SYMSAM('TMT',A) = SUM(C, tmmat(C,A));
SYMSAM('TQT',A) = SUM(C, tqmat(C,A));
SYMSAM('TVT',A) = SUM(C, tvmat(C,A));

*rebalancing taxes and trade margins

tmadj  = SUM(ACNT, SYMSAM('TMT',ACNT) ) - SUM(CTR, SYMSAM(CTR,'TMT'));
tmadj1(CTR) = tmadj * SYMSAM(CTR,'TMT')/SUM(CTRP, SYMSAM(CTRP,'TMT'));
tqadj   = SUM(ACNT, SYMSAM('TQT',ACNT) ) - SYMSAM('GOV','TQT');
tvadj   = SUM(ACNT, SYMSAM('TVT',ACNT) ) - SYMSAM('GOV','TVT');

SYMSAM('GOV','TQT') = SYMSAM('GOV','TQT') + tqadj;
SYMSAM('GOV','TVT') = SYMSAM('GOV','TVT') + tvadj;
SYMSAM(CTR,'TMT') = SYMSAM(CTR,'TMT') + tmadj1(CTR) ;
SYMSAM(A,CTR) = SYMSAM(A,CTR) + tmadj1(CTR) * primact(A,CTR);






*END OFF adjusting trade margins and taxes on commodities=======================




SYMSAM(FLAB,A) = SAM(FLAB,A) + labcorr(FLAB,A) ;





*REMOVING SMALLCELLS IN LABOUR USETABLE=========================================
labadj(FLAB)=0;
loop(FLAB,
loop(A,
if (SYMSAM(FLAB,A) < SMALLUSECELL,
labadj(FLAB)=labadj(FLAB)-SYMSAM(FLAB,A);
SYMSAM(FLAB,A) = 0;
);
);
);

display labadj;
SYMSAM('FACTAX',FLAB) = SYMSAM('FACTAX',FLAB) + labadj(FLAB) ;
SYMSAM('FACTAX','STOCK') = SYMSAM('FACTAX','STOCK') - SUM(FLAB, labadj(FLAB));


*END OFF REMOVING SMALLCELLS IN LABOUR USETABLE========================================




SYMSAM(FOP,A) = 0;
SYMSAM(FOP,A) = SUM(ACNTP, SYMSAM(A,ACNTP) ) - SUM(ACNT, SYMSAM(ACNT,A) ) ;



*adjusting small operting surplus===============================================
loop(A,
gg = 0.02* ( SUM(FLAB, SYMSAM(FLAB,A))+ SYMSAM('ACTTAX',A));
IF (SUM(FOP, SYMSAM(FOP,A)) < gg,
CAPADJ(A)= gg - SUM(FOP, SYMSAM(FOP,A));
);
);


SYMSAM(FOP,A) = SYMSAM(FOP,A) + CAPADJ(A);
SYMSAM('ACTTAX',A) = SYMSAM('ACTTAX',A) - CAPADJ(A);
SYMSAM('GOV','ACTTAX') = SYMSAM('GOV','ACTTAX') - SUM(A, CAPADJ(A));
SYMSAM('FACTAX','STOCK') = SYMSAM('FACTAX','STOCK') + SUM(A, CAPADJ(A)) - tqadj - tvadj;
SYMSAM('GOV','FACTAX') = SYMSAM('GOV','FACTAX') + SUM(A, CAPADJ(A)) - tqadj - tvadj;
*end of adjusting small operting surplus========================================
SYMSAM('STOCK',FCAP) = SUM(A, SYMSAM(FCAP,A))  ;


SYMSAM('TOTAL',ACNTP) = SUM(ACNT, SYMSAM(ACNT,ACNTP))  ;
SYMSAM(ACNT,'TOTAL') = SUM(ACNTP, SYMSAM(ACNT,ACNTP))  ;

SAM(AC,ACP) = SYMSAM(AC,ACP) ;

 SAMBALCHK(AC)   = SAM('TOTAL',AC) - SAM(AC,'TOTAL');

 ERRSAMBAL(AC)$(ABS(SAMBALCHK(AC)) GT 0.01) = 1/0;

 DISPLAY "Checking SAM balance", SAMBALCHK;


 SYMTM(C,A) = TMusecorr(C,A) + tmmatadj(C,A);
 SYMTQ(C,A) = TQusecorr(C,A) + tqmatadj(C,A);
 SYMTV(C,A) = TVusecorr(C,A) + tvmatadj(C,A);



Display
"Matrices to be copied into the new indata file:"
sam, tmmat, tqmat, tvmat;
Display
"Check the size of appropriteness of manipulations made"
tmadj, tqadj, tvadj, useadj, capadj
makecorr, usecorr, SYMTM, SYMTQ, SYMTV;


$libinclude xldump solverepio4 SYMIO.xls solver4!
$libinclude xldump error4 SYMIO.xls error4!



*$libinclude xldump repvark3 SYMIO.xls repvark3!
*$libinclude xldump repvarj3 SYMIO.xls repvarj3!

$libinclude xldump solverepio3 SYMIO.xls solver3!
$libinclude xldump error3 SYMIO.xls error3!



*$libinclude xldump repvark2 SYMIO.xls repvark2!
*$libinclude xldump repvarj2 SYMIO.xls repvarj2!

$libinclude xldump solverepio2 SYMIO.xls solver2!
$libinclude xldump error2 SYMIO.xls error2!

$libinclude xldump my SYMIO.xls my!
$libinclude xldump omega SYMIO.xls omega!


*$libinclude xldump repvark SYMIO.xls repvark!
*$libinclude xldump repvarj SYMIO.xls repvarj!

$libinclude xldump solverepio SYMIO.xls solver!
$libinclude xldump error SYMIO.xls error!

$libinclude xldump bcofdef SYMIO.xls bcofdef!

$libinclude xldump symsam symsam.xls

$libinclude xldump SAM NEWDATA.XLS SAM!
$libinclude xldump TMMAT NEWDATA.XLS TMMAT!
$libinclude xldump TQMAT NEWDATA.XLS TQMAT!
$libinclude xldump TVMAT NEWDATA.XLS TVMAT!
$libinclude xldump BINVMAT NEWDATA.XLS BINVMAT!
$libinclude xldump TQINV NEWDATA.XLS TQINV!
$libinclude xldump TMINV NEWDATA.XLS TMINV!
$libinclude xldump TVINV NEWDATA.XLS TVINV!
*END OFF CALCULATION OF NEW INDATA==============================================






*#*#*#*#*# THE END OF SAINT_SEC.GMS #*#*#*#*
